@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler superclass
-our $VERSION = '3.20241024'; # VERSION
+our $VERSION = '3.20250611'; # VERSION
 use Mail::Milter::Authentication::Exception;
 use Mail::Milter::Authentication::Resolver;
 use Digest::MD5 qw{ md5_hex };
@@ -450,7 +450,7 @@ sub remap_connect_callback {
         }
         else {
             $ip = $ip_remap->{ip};
-            $self->dbgout( 'RemappedConnect', $self->{'raw_ip_object'}->ip() . ' > ' . $ip->ip(), LOG_DEBUG );
+            $self->dbgout( 'RemappedConnect', $self->{'raw_ip_object'}->short() . ' > ' . $ip->short(), LOG_DEBUG );
        }
     }
     $self->{'ip_object'} = $ip;
@@ -489,7 +489,7 @@ sub top_connect_callback {
             $self->set_alarm( $timeout );
         }
 
-        $self->dbgout( 'ConnectFrom', $ip->ip(), LOG_DEBUG );
+        $self->dbgout( 'ConnectFrom', $ip->short(), LOG_DEBUG );
 
         my $callbacks = $self->get_callbacks( 'connect' );
         foreach my $handler ( @$callbacks ) {
@@ -534,7 +534,7 @@ sub remap_helo_callback {
             if ( $self->{'ip_object'}->ip() ne $ip_remap->{ip}->ip() ) {
                 # The mapped IP has been changed based on the HELO host received
                 $self->{'ip_object'} = $ip;
-                $self->dbgout( 'RemappedConnectHELO', $self->{'ip_object'}->ip() . ' > ' . $ip->ip(), LOG_DEBUG );
+                $self->dbgout( 'RemappedConnectHELO', $self->{'ip_object'}->short() . ' > ' . $ip->short(), LOG_DEBUG );
             }
             $helo_host = $ip_remap->{helo};
             $self->dbgout( 'RemappedHELO', $self->{'raw_helo_name'} . ' > ' . $helo_host, LOG_DEBUG );
@@ -1617,7 +1617,7 @@ sub is_authenticated {
 sub ip_address {
     my ($self) = @_;
     my $top_handler = $self->get_top_handler();
-    return $top_handler->{'ip_object'}->ip();
+    return $top_handler->{'ip_object'}->short();
 }
 
 
@@ -2302,7 +2302,7 @@ Mail::Milter::Authentication::Handler - Handler superclass
 
 =head1 VERSION
 
-version 3.20241024
+version 3.20250611
 
 =head1 DESCRIPTION
 
