@@ -4,11 +4,14 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for Local IP Connections
-our $VERSION = '3.20241024'; # VERSION
+our $VERSION = '3.20250611'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+use Net::IP;
 
 sub default_config {
-    return {};
+    return {
+        'ignore_local_ip_list' => [],
+    };
 }
 
 sub grafana_rows {
@@ -20,7 +23,7 @@ sub grafana_rows {
 
 sub is_local_ip_address {
     my ( $self, $ip ) = @_;
-    my $ip_address = $ip->ip();
+    my $ip_address = $ip->short();
     my $ip_type  = $ip->iptype();
     my $type_map = {
         'PRIVATE'              => 1,
@@ -44,6 +47,27 @@ sub is_local_ip_address {
         'UNIQUE-LOCAL-UNICAST' => 1,
         'LINK-LOCAL-UNICAST'   => 1,
     };
+    my $config = $self->handler_config();
+    if ( exists $config->{'ignore_local_ip_list'} ) {
+        foreach my $ignore_ip ( @{ $config->{'ignore_local_ip_list'} } ) {
+            my $ignore_ip_obj = Net::IP->new($ignore_ip);
+            if ( !$ignore_ip_obj ) {
+                $self->log_error( 'LocalIP: Could not parse ignore IP '.$ignore_ip );
+            }
+            else {
+                my $is_overlap = $ip->overlaps($ignore_ip_obj) || 0;
+                if (
+                    $is_overlap == $IP_A_IN_B_OVERLAP
+                    || $is_overlap == $IP_B_IN_A_OVERLAP     # Should never happen
+                    || $is_overlap == $IP_PARTIAL_OVERLAP    # Should never happen
+                    || $is_overlap == $IP_IDENTICAL
+                )
+                {
+                    return 0;
+                }
+            }
+        }
+    }
     $self->dbgout( 'IPAddress', "Address $ip_address detected as type $ip_type", LOG_DEBUG );
     return $type_map->{ $ip_type } || 0;
 }
@@ -85,7 +109,7 @@ Mail::Milter::Authentication::Handler::LocalIP - Handler class for Local IP Conn
 
 =head1 VERSION
 
-version 3.20241024
+version 3.20250611
 
 =head1 DESCRIPTION
 
@@ -93,7 +117,14 @@ Detect a Local IP address and act accordingly.
 
 =head1 CONFIGURATION
 
-No configuration options exist for this handler.
+        "LocalIP" : {                                   | Config the LocalIP Module
+                                                        | Check for LocalIP Addresses
+            "ignore_local_ip_list" : [                  | List of IP Addresses to treat as non-local
+                "127.0.0.1",                            | CIDR Ranges are valid syntax
+                "10.0.0.0/24"                           | This is useful, for test environments where non-local IPs aren't available
+                "fe80::/10",
+            ],
+        },
 
 =head1 AUTHOR
 
