@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for logging of headerss
-our $VERSION = '3.20241024'; # VERSION
+our $VERSION = '3.20250611'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
 
 use Sys::Syslog qw{:standard :macros};
@@ -28,7 +28,7 @@ sub connect_callback {
     my $config = $self->handler_config();
     return if ! $config->{connect};
     $self->dbgout( 'Logger', 'Connection host: ' . $hostname, LOG_INFO );
-    $self->dbgout( 'Logger', 'Connection IP: ' . $ip->ip(), LOG_INFO );
+    $self->dbgout( 'Logger', 'Connection IP: ' . $ip->short(), LOG_INFO );
     return;
 }
 
@@ -81,7 +81,7 @@ Mail::Milter::Authentication::Handler::Logger - Handler class for logging of hea
 
 =head1 VERSION
 
-version 3.20241024
+version 3.20250611
 
 =head1 DESCRIPTION
 
