@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: SMTP protocol handling
-our $VERSION = '3.20241024'; # VERSION
+our $VERSION = '3.20250611'; # VERSION
 use Digest::MD5 qw{ md5_hex };
 use Email::Date::Format qw{ email_date };
 use IO::Socket::INET;
@@ -449,7 +449,7 @@ sub smtp_command_mailfrom {
     $handler->remap_connect_callback( $host, Net::IP->new( $ip ) );
     $handler->remap_helo_callback( $helo );
 
-    $self->logdebug( "Inbound IP Address " . $handler->{'ip_object'}->ip() );
+    $self->logdebug( "Inbound IP Address " . $handler->{'ip_object'}->short() );
     $returncode = $handler->top_connect_callback( $host, $handler->{'ip_object'} );
     if ( $returncode == SMFIS_CONTINUE ) {
         $returncode = $handler->top_helo_callback( $handler->{'helo_name'} );
@@ -1111,7 +1111,7 @@ Mail::Milter::Authentication::Protocol::SMTP - SMTP protocol handling
 
 =head1 VERSION
 
-version 3.20241024
+version 3.20250611
 
 =head1 SYNOPSIS
 
